@@ -327,7 +327,7 @@ class KubeModel(ABC):
         self.__load_model()
         self._load_optimizer_redis()
         self._load_redis_test()
-        #self._load_file_test()
+        self._load_file_test()
 
         #self._load_optimizer_state()
 
@@ -341,7 +341,7 @@ class KubeModel(ABC):
         self.__save_model()
         self._save_optimizer_redis()
         self._save_redis_test()
-        #self._save_file_test()
+        self._save_file_test()
         #self._save_optimizer_state()
 
     def _batch_to_device(self, batch: Union[torch.Tensor, Iterable[torch.Tensor]]):
